@@ -23,20 +23,19 @@
 
 // ######################################################
 // Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
-// Last modif. : 26 Aug.2011, Carry le Rouet, J.M.Sellier
+// Last modif. : 31 Aug.2011, Carry le Rouet, J.M.Sellier
 // ######################################################
 
-// conduction band calculated using the model : sp3s* (see Vogl)
-// data interpolated by a 10-th order polynomial
+// Parabolic Conduction Band
 
-CB_FULL[ALSB][0]=-1.4718e+07;
-CB_FULL[ALSB][1]=-1.1075e+12;
-CB_FULL[ALSB][2]=-5.5306e+10;
-CB_FULL[ALSB][3]=-2.5814e+12;
-CB_FULL[ALSB][4]=-7.1981e+13;
-CB_FULL[ALSB][5]=2.4701e+12;
-CB_FULL[ALSB][6]=-3.3029e+10;
-CB_FULL[ALSB][7]=2.1041e+08;
-CB_FULL[ALSB][8]=-5.7113e+05;
-CB_FULL[ALSB][9]=2.1119e+02;
-CB_FULL[ALSB][10]=1.8559e+00;
+CB_FULL[ALSB][0]=+5.3706e+23;
+CB_FULL[ALSB][1]=-2.6626e+22;
+CB_FULL[ALSB][2]=+5.5766e+20;
+CB_FULL[ALSB][3]=-6.4249e+18;
+CB_FULL[ALSB][4]=+4.4457e+16;
+CB_FULL[ALSB][5]=-1.8950e+14;
+CB_FULL[ALSB][6]=+4.9115e+11;
+CB_FULL[ALSB][7]=-7.3542e+08;
+CB_FULL[ALSB][8]=+1.1316e+07;
+CB_FULL[ALSB][9]=-1.8334e+02;
+CB_FULL[ALSB][10]=0.0; //1.2999e-02;
