@@ -1,15 +1,12 @@
-/* archimedes.c -- This code is a simulator for Submicron 2D III-V
-   semiconductor Devices (along with SiO2). It implements the Monte Carlo method 
-   and a simplified version of MEP model for the simulation of the 
-   semiclassical Boltzmann equation for both electrons and holes.
-   It also includes some quantum effects by means of effective
-   potential method. It is also able to simulate applied
-   magnetic fields along with self consistent Faraday equation.
+/* archimedes.c -- This belongs to GNU archimedes.
 
-   Copyright (C) 2004-2011 Jean Michel Sellier
+   Archimedes is a simulator for Submicron and Nanoscaled
+   2D III-V Semiconductor Devices.
+
+   Copyright (C) 2004-2011 Jean Michel D. Sellier
    <jeanmichel.sellier@gmail.com>
    <jsellier@purdue.edu>
- 
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
@@ -22,14 +19,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 */
 
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 1.2.0
+// Version   : release 2.0.0
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 29 Aug 2011, Carry le Rouet, France, Jean Michel Sellier.
+// Last Revision : 15 Sept. 2011, Carry le Rouet, France, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -55,6 +53,10 @@
 #define KANE 0
 #define PARABOLIC 1
 #define FULL 2
+#define QEP_BOHM 0
+#define QEP_CALIBRATED_BOHM 1
+#define QEP_FULL 2
+#define QEP_DENSITY_GRADIENT 3
 #define MN3 4
 #define NXM 308
 #define NYM 308
@@ -111,6 +113,7 @@ int SAVEALWAYS;
 int nx,ny;
 int ISEED,NP1,INUM,IV;
 int c,Model_Number,File_Format,Quantum_Flag;
+int NG,NE;
 int leid_flag;
 int SIO2_UP_FLAG;
 int SIO2_DOWN_FLAG;
@@ -121,6 +124,8 @@ int ACOUSTICPHONONS;
 int OPTICALPHONONS;
 int IMPURITYPHONONS;
 int CONDUCTION_BAND;
+int SAVE_MESH;
+int NODE_GEO[3][(NXM+1)*(NYM+1)];
 
 // All "real"'s here...
 real u2d[NXM+1][NYM+1][MN3+1];
@@ -174,6 +179,10 @@ real EMIN[NOAMTIA+1][4];
 real XVAL[NOAMTIA+1];
 real LATTCONST[NOAMTIA+1];
 real CB_FULL[NOAMTIA+1][11];
+real QEP_ALPHA;
+real QEP_GAMMA;
+real QEP_MODEL;
+real COORD[2][(NXM+1)*(NYM+1)];
 
 // All structures here...
 time_t binarytime;
@@ -188,6 +197,7 @@ FILE *fp;
 // All strings here...
 static char *progname;
 
+#include "mesher.h"
 #include "poissonbcs.h"
 #include "faradaybcs.h"
 #include "media.h"
@@ -300,7 +310,7 @@ Report bugs to jeanmichel.sellier@gmail.com or jsellier@purdue.edu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 1.2.0\n");
+      printf("archimedes - GNU archimedes 2.0.0\n");
       /* xgettext: no-wrap */
       printf("");
       printf("\
@@ -546,6 +556,10 @@ For more information about these matters, see the file named COPYING.\n",
      Read_Input_File();
 // ===========================================================
 
+// Construction of the mesh for the electrostatic potential
+// (to properly take into account the oxyde layers)
+     mesher();
+
 // III-V Semiconductor materials energy gap (depending on the lattice temperature)
      printf("\n");
      EG[SILICON]=1.21-3.333e-4*TL;
