@@ -1,4 +1,4 @@
-/* particlecreation.h -- This file is part of Archimedes release 0.1.0.
+/* particlecreation.h -- This file is part of Archimedes release 1.2.0
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -24,8 +24,8 @@
 
 
 // ######################################################
-// Created on 06 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 10 Sep.2007, Siracusa, J.M.Sellier
+// Created on 06 sep.2004, Siracusa, Italy, J.M.Sellier
+// Last modif. : 26 Aug.2011, Carry le Rouet, France, J.M.Sellier
 // ######################################################
 
 // create a new super-particle on the edge
@@ -38,6 +38,8 @@ inline
 void
 creation(int i,real t,int edge)
 {
+ int iaux;
+ int iv;
  int ii,j;
  real c1,c2,c3,
       c4,c5,c6,c7;
@@ -59,14 +61,23 @@ creation(int i,real t,int edge)
 
 // creation of the particle pseudo-wave vector k=(KX,KY,KZ)
 // in the (i,j)-th cell
- ii=(int)(X/dx)+1;
- j=(int)(Y/dy)+1;
+ ii=(int)(X/dx+1.5);
+ j=(int)(Y/dy+1.5);
  if(ii<=1) ii=1;
  if(j<=1) j=1;
- if(ii>=nx) ii=nx;
- if(j>=ny) j=ny;
+ if(ii>=nx+1) ii=nx+1;
+ if(j>=ny+1) j=ny+1;
+ if(NOVALLEY[i_dom[ii][j]]==1){
+   iv=1;
+   iaux=0;
+ }
+ if(NOVALLEY[i_dom[ii][j]]==2){
+   iv=iaux=1;
+// 20% of the created particles belongs to the L-valley
+   if(rnd()>=0.8) iv=iaux=2;
+ }
  c1=log(rnd());
- c2=SMH[i_dom[ii][j]][0]*sqrt(-1.5*BKTQ*c1*(1.-alphaK[i_dom[ii][j]][1]*1.5*BKTQ*c1));
+ c2=SMH[i_dom[ii][j]][iaux]*sqrt(-1.5*BKTQ*c1*(1.-alphaK[i_dom[ii][j]][iv]*1.5*BKTQ*c1));
  c3=rnd();
  c4=sqrt(1.-c3*c3);
  c5=2.*PI*rnd();
@@ -75,7 +86,7 @@ creation(int i,real t,int edge)
  KX=c2*c3;
  KY=c2*c4*c6;
  KZ=c2*c4*c7;
- IV=1;
+ IV=iv;
  TS=t-log(rnd())/GM[i_dom[ii][j]];
  if(edge==2) KY=-KY;
  if(edge==1) KX=-KX;
