@@ -1,13 +1,12 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.1.4
-   Archimedes is a simulator for Submicron 2D III-V semiconductor
-   Devices. It implements the Monte Carlo method and Hybrid MEP model
-   for the simulation of the semiclassical Boltzmann equation for both
-   electrons and holes. It also includes the quantum effects by means 
-   of effective potential method. It is now able to simulate applied
-   magnetic fields along with self consistent Faraday equation.
+/* readinputfile.h -- This file is part of GNU archimedes
+
+   Archimedes is a simulator for Submicron and Nanoscaled
+   2D III-V Semiconductor Devices.
+
+   Copyright (C) 2004-2011 Jean Michel D. Sellier
+   <jeanmichel.sellier@gmail.com>
+   <jsellier@purdue.edu>
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
- 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
@@ -20,18 +19,18 @@
 
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 */
 
 
-// ######################################################
+// ##################################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 15 september 2007, Siracusa, J.M.Sellier
-// ######################################################
+// Last modif. : 06 september 2011, Carry le Rouet, France, J.M.Sellier
+// ##################################################################
 
-// Read the geometrical and physical description of the device.
-// The input file is interpreted as in a script language.
-// For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.1.3
+// Parse the script describing the device.
+// 
+// For the syntax see the manual
 
 void
 Read_Input_File(void)
@@ -48,14 +47,21 @@ Read_Input_File(void)
 // in the input file we have
 // the following values.
 // ============================
- XVAL[ALXINXSB]=XVAL[ALXIN1XSB]=0.5;
+ OPTICALPHONONS=ON;  // Optical phonons scattering ON by default
+ ACOUSTICPHONONS=ON; // Acoustic phonons scattering ON by default
+ IMPURITYPHONONS=ON; // Impurity phonons scattering ON by default
+ CONDUCTION_BAND=KANE;   // Kane approximation by default
+ QEP_ALPHA=0.5; // alpha parameter for quantum effective potential
+ QEP_GAMMA=1.0; // gamma parameter for quantum effective potential
+ QEP_MODEL=QEP_BOHM; // Bohm potential by default (if QEP is ON)
+ SAVE_MESH=OFF; // dont save the mesh by default
+ XVAL[ALXINXSB]=XVAL[ALXIN1XSB]=XVAL[INXGA1XAS]=XVAL[INXAL1XAS]=XVAL[INXGAXXAS]=0.5;
  Model_Number=MCE; // here we choose the model
  nx=50; // default # of cells in x-direction
  ny=50; // default # of cells in y-direction
  TF=5.0e-12; // Default Final Time in seconds
  DT=0.001e-12; // Default constant time step
  TAUW=0.4e-12; // Default Energy relaxation time
- msh=mstarHSILICON; // coefficient of the Si heavy hole effective mass
  FARADAYFLAG=0; // no evolution of magnetic field taken into account as default (B = 0 or const.)
 // standard doping concentration
  for(i=1;i<=nx+1;i++)
@@ -113,19 +119,21 @@ Processing the input file\n\
     fscanf(fp,"%s",s);
     if(strcmp(s,"SILICON")==0){
         type=SILICON;
-        msh=mstarHSILICON;
     }
     else if(strcmp(s,"GAAS")==0){
         type=GAAS;
-        msh=mstarHGAAS;
     }
     else if(strcmp(s,"GERMANIUM")==0){
         type=GERMANIUM;
-        msh=mstarHGERMANIUM;
     }
     else if(strcmp(s,"INSB")==0) type=INSB;
     else if(strcmp(s,"ALSB")==0) type=ALSB;
     else if(strcmp(s,"ALAS")==0) type=ALAS;
+    else if(strcmp(s,"ALP")==0) type=ALP;
+    else if(strcmp(s,"GAP")==0) type=GAP;
+    else if(strcmp(s,"GASB")==0) type=GASB;
+    else if(strcmp(s,"INAS")==0) type=INAS;
+    else if(strcmp(s,"INP")==0) type=INP;
     else if(strcmp(s,"ALxINxSB")==0){
       real dum;
       type=ALXINXSB;
@@ -150,6 +158,42 @@ Processing the input file\n\
       XVAL[type]=dum;
       printf("AlxIn(1-x)Sb X = %g\n",XVAL[type]);
     }
+    else if(strcmp(s,"INxGA1-xAS")==0){
+      real dum;
+      type=INXGA1XAS;
+      fscanf(fp,"%lf",&dum);
+      XVAL[type]=dum;
+      if(XVAL[type]<0.){
+        printf("%s : x negative for InxGa(1-x)As!\n",progname);
+        exit(0);
+      }
+      XVAL[type]=dum;
+      printf("InxGa(1-x)As X = %g\n",XVAL[type]);
+    }
+    else if(strcmp(s,"INxAL1-xAS")==0){
+      real dum;
+      type=INXAL1XAS;
+      fscanf(fp,"%lf",&dum);
+      XVAL[type]=dum;
+      if(XVAL[type]<0.){
+        printf("%s : x negative for InxAl(1-x)As!\n",progname);
+        exit(0);
+      }
+      XVAL[type]=dum;
+      printf("InxAl(1-x)As X = %g\n",XVAL[type]);
+    }
+    else if(strcmp(s,"INxGAxAS2")==0){
+      real dum;
+      type=INXGAXXAS;
+      fscanf(fp,"%lf",&dum);
+      XVAL[type]=dum;
+      if(XVAL[type]<0.){
+        printf("%s : x negative for InxGaxAs2!\n",progname);
+        exit(0);
+      }
+      XVAL[type]=dum;
+      printf("InxGaxAs2 X = %g\n",XVAL[type]);
+    }
     else{
       printf("%s : unknown specified material!\n",progname);
       exit(0);
@@ -214,7 +258,7 @@ Processing the input file\n\
         exit(EXIT_FAILURE);
     }
   }
-// Specified the number of spatial step in x direction
+// Specify the number of cells in x direction
   else if(strcmp(s,"XSPATIALSTEP")==0){
     fscanf(fp,"%lf",&num);
     nx=(int) num;
@@ -226,10 +270,10 @@ Processing the input file\n\
       printf("%s: you have to define the x-length first\n",progname);
       exit(EXIT_FAILURE);
     }
-    dx=LX/nx; // spatial step in x-direction
+    dx=LX/nx; // length of cell in x-direction
     printf("XSPATIALSTEP = %d ---> Ok\n",nx);
   }
-// Specified the number of spatial step in y direction
+// Specify the number of cells in y direction
   else if(strcmp(s,"YSPATIALSTEP")==0){
     fscanf(fp,"%lf",&num);
     ny=(int) num;
@@ -241,10 +285,10 @@ Processing the input file\n\
       printf("%s: you have to define the y-length first\n",progname);
       exit(EXIT_FAILURE);
     }
-    dy=LY/ny; // spatial step in y-direction
+    dy=LY/ny; // length of cell in y-direction
     printf("YSPATIALSTEP = %d ---> Ok\n",ny);
   }
-// configuration of the final time of simulation
+// specify the final time of simulation
   else if(strcmp(s,"FINALTIME")==0){
     fscanf(fp,"%lg",&num);
     TF=num;
@@ -680,13 +724,27 @@ Processing the input file\n\
      printf("---> Ok\n");
     }
   }
+  else if(strcmp(s,"QEP")==0){
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0) Quantum_Flag=1;
+   else if(strcmp(s,"OFF")==0) Quantum_Flag=0;
+   else{
+     printf("%s : QEP can be set on ON and OFF only.\n",progname);
+     exit(0);
+   }
+   printf("QUANTUM EFFECTIVE POTENTIAL %s ---> Ok\n",s);
+  }
   else if(strcmp(s,"NOQUANTUMEFFECTS")==0){
+// WE KEEP IT ONLY FOR BACK COMPATIBILITY
     Quantum_Flag=0;
-    printf("QUANTUM EFFECTS = NO --->Ok\n");
+    printf("WARNING! This command is DEPRECATED! Use QEP instead!\n");
+    printf("QUANTUM EFFECTIVE POTENTIAL = OFF --->Ok\n");
   }
   else if(strcmp(s,"QUANTUMEFFECTS")==0){
+// WE KEEP IT ONLY FOR BACK COMPATIBILITY
     Quantum_Flag=1;
-    printf("QUANTUM EFFECTS = YES --->Ok\n");
+    printf("WARNING! This command is DEPRECATED! Use QEP instead!\n");
+    printf("QUANTUM EFFECTIVE POTENTIAL = ON --->Ok\n");
   }
   else if(strcmp(s,"MEDIA")==0){
     fscanf(fp,"%lf",&num);
@@ -713,7 +771,7 @@ Processing the input file\n\
 // Faraday equation ON or OFF
    fscanf(fp,"%s",s);
    if(strcmp(s,"ON")==0) FARADAYFLAG=1;
-   else if(strcmp(s,"OFF")==0) FARADAYFLAG=1;
+   else if(strcmp(s,"OFF")==0) FARADAYFLAG=0;
    else{
      printf("%s : command FARADAY accept ON or OFF.\n",progname);
      exit(0);
@@ -741,6 +799,112 @@ Processing the input file\n\
         }
     printf("Constant Magnetic Field %f %f %f %f %f ---> Ok\n",xi,yi,xf,yf,value);
   }
+  else if(strcmp(s,"OPTICALSCATTERING")==0){
+// specify if the Optical phonons scateering has to be taken into account
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0){
+    OPTICALPHONONS=ON;
+    printf("OPTICAL PHONONS SCATTERING = ON ---> Ok\n");
+   }
+   else if(strcmp(s,"OFF")==0){
+    OPTICALPHONONS=OFF;
+    printf("OPTICAL PHONONS SCATTERING = OFF ---> Ok\n");
+   }
+   else {
+    printf("%s : command OPTICALSCATTERING accept ON or OFF.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"ACOUSTICSCATTERING")==0){
+// specify if the Acoustic phonons scattering has to be taken into account
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0){
+    ACOUSTICPHONONS=ON;
+    printf("ACOUSTIC PHONONS SCATTERING = ON ---> Ok\n");
+   }
+   else if(strcmp(s,"OFF")==0){
+    ACOUSTICPHONONS=OFF;
+    printf("ACOUSTIC PHONONS SCATTERING = OFF ---> Ok\n");
+   }
+   else {
+    printf("%s : command ACOUSTINGSCATTERING accept ON or OFF.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"IMPURITYSCATTERING")==0){
+// specify if the Acoustic phonons scattering has to be taken into account
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0){
+    IMPURITYPHONONS=ON;
+    printf("IMPURITY PHONONS SCATTERING = ON ---> Ok\n");
+   }
+   else if(strcmp(s,"OFF")==0){
+    IMPURITYPHONONS=OFF;
+    printf("IMPURITY PHONONS SCATTERING = OFF ---> Ok\n");
+   }
+   else {
+    printf("%s : command IMPURITYSCATTERING accept ON or OFF.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"CONDUCTIONBAND")==0){
+// Specify the conduction band model
+// Possible choices are PARABOLIC, KANE, FULL
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"PARABOLIC")==0){
+    CONDUCTION_BAND=PARABOLIC;
+    printf("CONDUCTION BAND = PARABOLIC ---> Ok\n");
+   }
+   else if(strcmp(s,"KANE")==0){
+    CONDUCTION_BAND=KANE;
+    printf("CONDUCTION BAND = KANE ---> Ok\n");
+   }
+   else if(strcmp(s,"FULL")==0){
+    CONDUCTION_BAND=FULL;
+    printf("CONDUCTION BAND = FULL BAND ---> Ok\n");
+   }
+   else {
+    printf("%s : Unknown specified conduction band model.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"QEP_PARAMETERS")==0){
+// Specify the parameters alpha and gamma for the
+// quantum effective potential approximation
+   real tmp;
+   fscanf(fp,"%lf",&tmp);
+   QEP_ALPHA=tmp;
+   fscanf(fp,"%lf",&tmp);
+   QEP_GAMMA=tmp;
+   printf("QUAT. EFF. POT. PARAMETERS\nALPHA = %f --> Ok\nGAMMA = %f --> Ok\n",QEP_ALPHA,QEP_GAMMA);
+  }
+  else if(strcmp(s,"QEP_MODEL")==0){
+// Specify the QEP model to be simulated
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"CALIBRATED_BOHM")==0){
+    QEP_MODEL=QEP_CALIBRATED_BOHM;
+    printf("QEP_MODEL = CALIBRATED BOHM POTENTIAL ---> Ok\n");
+   }
+   else if(strcmp(s,"BOHM")==0){
+    QEP_MODEL=QEP_BOHM;
+    printf("QEP_MODEL = BOHM POTENTIAL ---> Ok\n");
+   }
+   else if(strcmp(s,"FULL")==0){
+    QEP_MODEL=QEP_FULL;
+    printf("QEP_MODEL = FULL EFFECTIVE POTENTIAL ---> Ok\n");
+   }
+   else if(strcmp(s,"DENSITY_GRADIENT")==0){
+    QEP_MODEL=QEP_DENSITY_GRADIENT;
+    printf("QEP_MODEL = DENSITY GRADIENT ---> Ok\n");
+   } else {
+    printf("Unknown specified quant. eff. potential!\n");
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"SAVEMESH")==0){
+   SAVE_MESH=ON;
+   printf("SAVE THE MESH --> Ok\n");
+  }
 // elseif(strcmp(s,"")==0){
  }while(!feof(fp));
 // computation of the maximum doping density
